#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2002 Free Software Foundation
#
# FILE:
# GNClient.py
#
# DESCRIPTION:
# Client startup file that creates a navigation menu from a file
#
# NOTES:
#

import pstats
import os
import os.path
import sys
import urllib
import string

from gnue.navigator.GNParser import loadProcesses
from gnue.navigator import Actions
from gnue.common import GDebug
from gnue.common.FileUtils import openResource
from gnue.common import GDataObjects, GConnections
from gnue.common.GClientApp import *
from gnue.navigator import VERSION

from GNConfig import ConfigOptions as NavigatorConfigOptions

# TODO: Please go away!!!!!
from gnue.forms.GFConfig import ConfigOptions
from gnue.reports.GRConfig import ConfigOptions as ReportsConfigOptions

class GNClient(GClientApp):
  #
  # GClientApp() overrides
  #
  VERSION = VERSION
  COMMAND = "gnue-navigator"
  NAME = "GNUe Navigator"
  USAGE = "[options] file"
  COMMAND_OPTIONS = [
      [ 'user_interface', 'u', 'user_interface', 1, 'gui', 'type',
          'The currently supported values for <type> are ' \
        + 'gui, web (a themable web-like interface), and text' ],
      [ 'splash_screen','s','no-splash', 0, None, None,
          'Disables the splash screen'],
      [ 'gnome_menu',None,'install-gnome-menu', 0, None, None,
          'Installs a menu structure into your local GNOME session'],
      [ 'kde_menu',None,'install-kde-menu', 0, None, None,
          'Installs a menu structure into your local KDE session']
      ]
  SUMMARY = \
     "GNUe Navigator is the primary menuing interface to the GNU Enterprise system."

  #
  # Initialize the class
  #
  def __init__(self, connections=None):
    GClientApp.__init__(self, connections,'forms', ConfigOptions)
    self.configurationManager.loadApplicationConfig(section="navigator",defaults=NavigatorConfigOptions)
    self.configurationManager.loadApplicationConfig(section="reports",defaults=ReportsConfigOptions)
    self.configurationManager.registerAlias('gConfigNav', 'navigator')
    self.configurationManager.registerAlias('gConfigForms', 'forms')
    self.configurationManager.registerAlias('gConfigReports', 'reports')

    self._formInstances = {}
    self._lastSerialNumber = 0

    self.ui_type = self.OPTIONS['user_interface']
    if gConfigNav('disableSplash') == '1':
      self.disableSplash = 1
    else:
      self.disableSplash = self.OPTIONS['splash_screen']

  #
  # Run the client application
  #
  # GClientApp().run() override
  #
  def run(self):

    # assign menu file from 1st free argument
    try:
      processFile = self.ARGUMENTS[0]
    except:
      try:
        if string.split(string.lower(os.path.basename(sys.argv[0])),'.')[0] not in ('gnue-navigator','gncvs'):
          processFile = os.environ['INSTALL_PREFIX']+'/'+gConfigNav('ProcessDir')+"/"+os.path.basename(sys.argv[0])+".gpd"
        else:
          raise IndexError
      except IndexError:
        self.handleStartupError ("No Process Definition File Specified.")


    fileHandle = openResource(processFile)
    nav = loadProcesses (fileHandle)
    fileHandle.close()



    # Handle any action commands
    if self.OPTIONS['kde_menu']:
      from gnue.navigator.Actions import kde_menu
      kde_menu.run(nav, self.ARGUMENTS[1:])
      sys.exit()

    if self.OPTIONS['gnome_menu']:
      from gnue.navigator.Actions import gnome_menu
      gnome_menu.run(nav, self.ARGUMENTS[1:])
      sys.exit()



    # Initialize user interface (defaults to gui)
    #  If the DISPLAY var isn't set then switch to text
    if self.ui_type == 'web':
      if os.environ.has_key('DISPLAY') or os.name != 'posix':
        import UIwxweb as interface
      else:
        self.ui_type='text'

    if self.ui_type == 'gui':
      if os.environ.has_key('DISPLAY') or os.name != 'posix':
        import UIwxpython as interface
      else:
        self.ui_type='text'

    if self.ui_type == 'text' :
      import UItext as interface

    # add connections object to top object
    nav._connections=self.connections
    
    interface.Instance(nav).run(self.connections)

if __name__ == '__main__':
  GNClient().run()


